pub struct ExactObjectVersion(/* private fields */);Expand description
Opaque provider revision for an exact mutable object.
The provider assigns the value and interprets it during conditional replacement. Coven only requires that it is present and retains it beside the exact bytes observed at that revision.
Implementations
Sourceimpl ExactObjectVersion
impl ExactObjectVersion
pub fn from_provider(value: String) -> Result<Self, StorageError>
pub fn as_provider(&self) -> &str