pub struct PreparedStoreOperationCommit {
pub common: PreparedStoreOperationCommon,
pub head: StoreDeviceHead,
pub head_object: ExactObjectRef,
pub history_evidence: RetainedMergeCommitEvidence,
}Fields
common: PreparedStoreOperationCommonhead: StoreDeviceHeadhead_object: ExactObjectRefhistory_evidence: RetainedMergeCommitEvidenceImplementations
Sourceimpl PreparedStoreOperationCommit
impl PreparedStoreOperationCommit
pub fn merge_membership_activation_remote_objects( &self, transition: &PreparedMembershipTransition, publication: &PreparedMembershipPublication, wraps: &[PreparedWrappedStoreKey], ) -> Result<Vec<ClosedRemoteObject>, PreparedCommitError>
pub fn merge_membership_resolution_remote_objects( &self, transition: &PreparedMembershipTransition, publication: &PreparedMembershipPublication, resolution: &StoreMembershipConflictResolution, reference: &StoreMembershipConflictResolutionRef, ) -> Result<Vec<ClosedRemoteObject>, PreparedCommitError>
pub fn merge_owner_promotion_remote_objects( &self, transition: &PreparedMembershipTransition, publication: &PreparedMembershipPublication, wrapped_key: &PreparedWrappedStoreKey, ) -> Result<Vec<ClosedRemoteObject>, PreparedCommitError>
pub fn validate_closed_shape(&self) -> Result<(), PreparedCommitError>
Sourcepub fn prepared_head(&self) -> Result<PreparedExactObject, PreparedCommitError>
pub fn prepared_head(&self) -> Result<PreparedExactObject, PreparedCommitError>
The activation head prepared for upload: its canonical bytes, re-derived from the value, under the exact object the operation names.
pub fn publication(&self) -> (&StoreDeviceHead, &ExactObjectRef)
pub fn head_ref(&self) -> StoreDeviceHeadRef
pub fn acknowledgement_remote_objects( &self, acknowledgement: &ExactProtocolObject<StoreAck>, ) -> Result<Vec<ClosedRemoteObject>, PreparedCommitError>
pub fn circle_acknowledgement_remote_objects( &self, acknowledgement: &ExactProtocolObject<CircleAck>, ) -> Result<Vec<ClosedRemoteObject>, PreparedCommitError>
pub fn adopt_merge_head( &mut self, winner: StoreDeviceHead, object: ExactObjectRef, ) -> Result<(), PreparedCommitError>
pub fn attach_merge_membership_proof_with( &mut self, publication: &PreparedMembershipPublication, resolution_value: Option<&StoreMembershipConflictResolution>, ) -> Result<(), PreparedCommitError>
Methods from Deref<Target = PreparedStoreOperationCommon>
Sourcepub fn prepared_commit(
&self,
) -> Result<PreparedExactObject, PreparedCommitError>
pub fn prepared_commit( &self, ) -> Result<PreparedExactObject, PreparedCommitError>
The commit prepared for upload: its canonical bytes, re-derived from the value, under the exact reference the operation names.