pub struct SamePrincipalStoreInstallation {
pub store_root: StoreProtocolRoot,
pub snapshot: StoreSnapshotRef,
pub metadata: SnapshotMeta,
pub authority: RetainedReplaySnapshotAuthority,
pub bootstrap: DeviceJoinBootstrapClosure,
}Expand description
The signed snapshot authority and exact Merge closure a same-provider joining device needs. The snapshot image remains in provider storage and is the only Store object downloaded after this response arrives.
Fields
store_root: StoreProtocolRootsnapshot: StoreSnapshotRefmetadata: SnapshotMetabootstrap: DeviceJoinBootstrapClosureTrait Implementations
Sourceimpl Clone for SamePrincipalStoreInstallation
impl Clone for SamePrincipalStoreInstallation
Sourcefn clone(&self) -> SamePrincipalStoreInstallation
fn clone(&self) -> SamePrincipalStoreInstallation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SamePrincipalStoreInstallation
impl<'de> Deserialize<'de> for SamePrincipalStoreInstallation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SamePrincipalStoreInstallation
impl PartialEq for SamePrincipalStoreInstallation
Sourcefn eq(&self, other: &SamePrincipalStoreInstallation) -> bool
fn eq(&self, other: &SamePrincipalStoreInstallation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SamePrincipalStoreInstallation
impl StructuralPartialEq for SamePrincipalStoreInstallation